﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace HeatmapTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.DecimalDegree;
            OpenStreetMapOverlay worldOverlay = new OpenStreetMapOverlay();
            Map1.MapUnit = GeographyUnit.Meter;
            string mapProjection = "+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs";
            Map1.Overlays.Add("OSM", worldOverlay);

            // Create the features 
            List<Feature> pointFeatures = new List<Feature>();
            Feature curFeature = new Feature(new PointShape(-117.905537, 48.5465695));
            curFeature.Id = "1";
            curFeature.ColumnValues.Add("Rank", "1");
            pointFeatures.Add(curFeature);

            curFeature = new Feature(new PointShape(-116.2034505, 43.6135002));
            curFeature.Id = "2";
            curFeature.ColumnValues.Add("Rank", "2");
            pointFeatures.Add(curFeature);

            curFeature = new Feature(new PointShape(-119.2844621, 46.2856907));
            curFeature.Id = "3";
            curFeature.ColumnValues.Add("Rank", "3");
            pointFeatures.Add(curFeature);

            // Create the projection for this data
            Proj4Projection proj = new Proj4Projection()
            {
                InternalProjectionParametersString = Proj4Projection.GetDecimalDegreesParametersString(),
                ExternalProjectionParametersString = mapProjection
            };

            //Create the layer
            FeatureSourceColumn rankColumn = new FeatureSourceColumn("Rank");
            InMemoryFeatureSource featureSource = new InMemoryFeatureSource(new FeatureSourceColumn[] { rankColumn }, pointFeatures);
            HeatLayer heatLayer = new HeatLayer(featureSource);
            heatLayer.FeatureSource.Projection = proj;

            // Init the heatstyle
            heatLayer.HeatStyle.IntensityColumnName = "Rank";
            // Set the IntensityRangeStart to .1 and it looks fine
            //heatLayer.HeatStyle.IntensityRangeStart = .1;
            heatLayer.HeatStyle.IntensityRangeStart = 1;
            heatLayer.HeatStyle.IntensityRangeEnd = 3;
            heatLayer.HeatStyle.PointRadius = 20;
            heatLayer.HeatStyle.PointRadiusUnit = DistanceUnit.Kilometer;

            // Add to the map
            LayerOverlay mainOverlay = new LayerOverlay(new Layer[] { heatLayer });
            mainOverlay.DrawingExceptionMode = DrawingExceptionMode.DrawException;
            Map1.Overlays.Add(mainOverlay);

            Application.Current.Dispatcher.BeginInvoke(new Action(() =>
            {
                heatLayer.Open();
                Map1.CurrentExtent = heatLayer.FeatureSource.GetBoundingBox();
                Map1.Refresh();
            }));

        }
    }
}
